/*
 * Copyright 2012 Amazon Technologies, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at:
 *
 *    http://aws.amazon.com/apache2.0
 *
 * This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES
 * OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and
 * limitations under the License.
 */
package com.amazonaws.memes;

import java.util.Date;

import com.amazonaws.services.dynamodb.datamodeling.DynamoDBAttribute;
import com.amazonaws.services.dynamodb.datamodeling.DynamoDBAutoGeneratedKey;
import com.amazonaws.services.dynamodb.datamodeling.DynamoDBHashKey;
import com.amazonaws.services.dynamodb.datamodeling.DynamoDBTable;

/**
 * Data model class for a meme creation job stored in Dynamo DB
 * 
 * @author zachmu
 */
@DynamoDBTable(tableName = "reinvent-memes")
public class MemeCreationJob {

    private String id;
    private String imageKey;
    private String topCaption;
    private String bottomCaption;
    private Date creationTime;
    private Date updateTime;
    private String finishedKey;
    private String status;
    private String createdBy;

    public static final String NEW_STATUS = "New";
    public static final String WORKING_STATUS = "Working";
    public static final String DONE_STATUS = "Done";
	public static final String FAILED_STATUS = "Failed";

    public MemeCreationJob() {
        status = "New";
    }

    @DynamoDBHashKey
    @DynamoDBAutoGeneratedKey
    public String getId() {
        return id;
    }

    public void setId(String id) {	
        this.id = id;
    }

    @DynamoDBAttribute
    public String getImageKey() {
        return imageKey;
    }

    public void setImageKey(String imageKey) {
        this.imageKey = imageKey;
    }

    @DynamoDBAttribute
    public String getTopCaption() {
        return topCaption;
    }

    public void setTopCaption(String topCaption) {
        this.topCaption = topCaption;
    }

    @DynamoDBAttribute
    public String getBottomCaption() {
        return bottomCaption;
    }

    public void setBottomCaption(String bottomCaption) {
        this.bottomCaption = bottomCaption;
    }

    @DynamoDBAttribute
    public Date getCreationTime() {
        return creationTime;
    }

    public void setCreationTime(Date creationTime) {
        this.creationTime = creationTime;
    }

    @DynamoDBAttribute
    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    @DynamoDBAttribute
    public String getFinishedKey() {
        return finishedKey;
    }

    public void setFinishedKey(String finishedKey) {
        this.finishedKey = finishedKey;
    }

    @DynamoDBAttribute
    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    @DynamoDBAttribute
    public String getCreatedBy() {
        return createdBy;
    }
    
    public void setCreatedBy(String createdBy) {
        this.createdBy = createdBy;
    }
}
